<?php
/**
 * Place order form metas.
 *
 * Responsible for creating metaboxes for order.
 *
 * @package    Wp_Travel_Engine
 * @subpackage Wp_Travel_Engine/includes
 * @author
 */
class Wp_Travel_Engine_Order_Meta {

	public function __construct() {
		$this->init();
	}

	function init() {
		add_action( 'add_meta_boxes', array( $this, 'wpte_booking_details_add_meta_boxes' ) );
		add_action( 'add_meta_boxes', array( $this, 'wpte_customer_add_meta_boxes' ) );
		add_action( 'add_meta_boxes', array( $this, 'wpte_customer_history_add_meta_boxes' ) );

		// Combined to update wp-travel-engine default meta.
		add_action( 'save_post', array( __CLASS__, 'save_post' ), 11, 3 );
	}

	public static function save_post( $post_id, $post, $update ) {

		if ( ! $post || ! in_array( $post->post_type, array( WP_TRAVEL_ENGINE_POST_TYPE, 'booking', 'customer', 'enquiry' ), ! 0 ) ) {
			return;
		}

		if ( 'booking' === $post->post_type ) {
			foreach ( array(
				'wp_travel_engine_booking_payment_status'  => array(
					'default'           => 'pending',
					'sanitize_callback' => function( $value ) {
						return sanitize_text_field( $value );
					},
				),
				'wp_travel_engine_booking_payment_gateway' => array(
					'sanitize_callback' => function( $value ) {
						return sanitize_text_field( $value );
					},
				),
				'wp_travel_engine_booking_payment_details' => array(
					'sanitize_callback' => function( $value ) {
						return wp_unslash( $value );
					},
				),
				'wp_travel_engine_booking_status'          => array(
					'sanitize_callback' => function( $value ) {
						return sanitize_text_field( $value );
					},
				),
			) as $meta_key => $args ) {
				if ( isset( $_POST[ $meta_key ] ) ) { // phpcs:ignore
					$meta_value = ( isset( $args['sanitize_callback'] ) ) ? call_user_func( $args['sanitize_callback'], $_POST[ $meta_key ] ) : wte_clean( wp_unslash( $_POST[ $meta_key ] ) ); // phpcs:ignore
					update_post_meta( $post_id, $meta_key, $meta_value );
				}
			}
		}

		if ( isset( $_POST['wp_travel_engine_booking_setting'] ) ) { // phpcs:ignore
			$settings = wte_clean( wp_unslash( $_POST['wp_travel_engine_booking_setting'] ) ); // phpcs:ignore
			update_post_meta( $post_id, 'wp_travel_engine_booking_setting', $settings );
		}
	}

	/**
	 * Place order form metabox.
	 *
	 * @since 1.0.0
	 */
	function wpte_booking_details_add_meta_boxes() {
		$screens = array( 'booking' );
		foreach ( $screens as $screen ) {
			add_meta_box(
				'booking_details_id',
				__( 'Booking Details', 'wp-travel-engine' ),
				array( $this, 'wp_travel_engine_booking_details_metabox_callback' ),
				$screen,
				'normal',
				'high'
			);
		}
	}

	// Tab for notice listing and settings
	public function wp_travel_engine_booking_details_metabox_callback() {
		include WP_TRAVEL_ENGINE_BASE_PATH . '/includes/backend/booking/booking-details.php';
	}

	/**
	 * Place order form metabox.
	 *
	 * @since 1.0.0
	 */
	function wpte_customer_add_meta_boxes() {
		$screens = array( 'customer' );
		foreach ( $screens as $screen ) {
			add_meta_box(
				'customer_id',
				__( 'Customer Details', 'wp-travel-engine' ),
				array( $this, 'wp_travel_engine_customer_metabox_callback' ),
				$screen,
				'normal',
				'high'
			);
		}
	}

	// Tab for notice listing and settings
	public function wp_travel_engine_customer_metabox_callback() {
		include WP_TRAVEL_ENGINE_BASE_PATH . '/includes/backend/booking/customer.php';
	}

	/**
	 * Customer History Metabox
	 *
	 * @since 1.0.0
	 */
	function wpte_customer_history_add_meta_boxes() {
		$screens = array( 'customer' );
		foreach ( $screens as $screen ) {
			add_meta_box(
				'customer_history_id',
				__( 'Customer History', 'wp-travel-engine' ),
				array( $this, 'wp_travel_engine_customer_history_metabox_callback' ),
				$screen,
				'normal',
				'high'
			);
		}
	}

	// Tab for notice listing and settings
	public function wp_travel_engine_customer_history_metabox_callback() {
		include WP_TRAVEL_ENGINE_BASE_PATH . '/includes/backend/booking/customer-history.php';
	}

}
$obj = new Wp_Travel_Engine_Order_Meta();
